@@ -30,7 +30,7 @@
 #ifndef _GNOME_PILOT_CAPPLET_H_
 #define _GNOME_PILOT_CAPPLET_H_
 
-#include <gpilotd/gnome-pilot-client.h>
+#include <gnome-pilot-client.h>
 #include <gtk/gtk.h>
 
 #ifdef __cplusplus
