@@ -44,18 +44,18 @@ typedef struct _GnomePilotCDialogPrivate GnomePilotCDialogPrivate;
 typedef struct _GnomePilotCDialogClass   GnomePilotCDialogClass;
 
 struct _GnomePilotCDialog {
-	GtkObject parent;
+	GObject parent;
 
 	GnomePilotCDialogPrivate *priv;
 };
 
 struct _GnomePilotCDialogClass {
-	GtkObjectClass parent_class;
+	GObjectClass parent_class;
 };
 
 
 GType    gnome_pilot_cdialog_get_type (void);
-GtkObject *gnome_pilot_cdialog_new      (ConduitState *state);
+GObject *gnome_pilot_cdialog_new      (ConduitState *state);
 
 GnomePilotConduitSyncType gnome_pilot_cdialog_first_sync_type (GnomePilotCDialog *gpcd);
 GnomePilotConduitSyncType gnome_pilot_cdialog_sync_type (GnomePilotCDialog *gpcd);
