@@ -331,10 +331,8 @@ get_default_pilot (PilotState *state)
 	pilot->name = next_pilot_name (state);
 	pilot->sync_options.basedir = g_build_filename (g_get_home_dir (),
 							pilot->name, NULL);
-#ifdef PILOT_LINK_0_12
 	pilot->pilot_charset =
 	    g_strdup(get_default_pilot_charset());
-#endif
 
 	return pilot;
 }
@@ -362,7 +360,7 @@ insert_numeric_callback (GtkEditable *editable, const gchar *text,
 	
 	for (i =0; i<len; i++) {
 		if (!isdigit (text[i])) {
-			g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
+			g_signal_stop_emission_by_name (G_OBJECT (editable), "insert_text");
 			return;
 		}
 	}
@@ -379,7 +377,7 @@ insert_username_callback (GtkEditable *editable, const gchar *text,
 	if (*position == 0 && len > 0) {
 		utf8_char = g_utf8_get_char_validated (text, -1);
 		if (!g_unichar_isalpha (utf8_char)) {
-			g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
+			g_signal_stop_emission_by_name (G_OBJECT (editable), "insert_text");
 		}
 	} else {
 		gchar *p = (char *) text; 
@@ -387,7 +385,7 @@ insert_username_callback (GtkEditable *editable, const gchar *text,
 		while (p && *p) {
 			utf8_char = g_utf8_get_char_validated (p, -1);
 			if (!g_unichar_isalnum (utf8_char) && !g_unichar_isspace (utf8_char)) {
-				g_signal_stop_emission_by_name (GTK_OBJECT (editable), 
+				g_signal_stop_emission_by_name (G_OBJECT (editable), 
 							     "insert_text");
 			}
 			p = g_utf8_find_next_char (p, NULL);
@@ -405,18 +403,16 @@ insert_device_callback (GtkEditable *editable, const gchar *text,
 	curname = gtk_entry_get_text (GTK_ENTRY (editable));
 	if (*curname == '\0' && len > 0) {
 		if (text[0]!='/'
-#ifdef PILOT_LINK_0_12
 		    /* usb: pseudo-device is available from pilot-link 0.12.0 */
 		    && text[0]!='u'
-#endif
 		    ) {
-			g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
+			g_signal_stop_emission_by_name (G_OBJECT (editable), "insert_text");
 			return;
 		} 
 	} else {
 		for (i =0;i<len;i++)
 			if (!(isalnum (text[i]) || text[i]=='/' || text[i]==':')) {
-				g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
+				g_signal_stop_emission_by_name (G_OBJECT (editable), "insert_text");
 				return;
 			}
 	}
@@ -588,9 +584,6 @@ check_base_directory (const gchar *dir_name, gchar **errstr)
 gboolean
 check_pilot_charset (const gchar *charset, gchar **errstr)
 {
-#ifndef PILOT_LINK_0_12
-	return TRUE;
-#else
 	iconv_t cd;
 
 	if (charset == NULL || *charset == '\0')
@@ -607,11 +600,10 @@ check_pilot_charset (const gchar *charset, gchar **errstr)
 
 	iconv_close(cd);
 	return TRUE;
-#endif
 }
 
 void
-read_device_config (GtkObject *object, GPilotDevice* device)
+read_device_config (GObject *object, GPilotDevice* device)
 {
 	GtkWidget *port_entry, *speed_combo, *name_entry;
 	GtkWidget *usb_radio, *irda_radio, *network_radio, *timeout_spinner, *bluetooth_radio;
@@ -653,12 +645,10 @@ read_device_config (GtkObject *object, GPilotDevice* device)
 }
 
 void
-read_pilot_config (GtkObject *object, GPilotPilot *pilot)
+read_pilot_config (GObject *object, GPilotPilot *pilot)
 {
 	GtkWidget *id, *name, *pname, *basedir, *menu;
-#ifdef PILOT_LINK_0_12
 	GtkWidget *charset;
-#endif
 	const gchar *num;
 	gint pilotid;
 	g_return_if_fail (pilot!= NULL);
@@ -667,9 +657,7 @@ read_pilot_config (GtkObject *object, GPilotPilot *pilot)
 	name    = g_object_get_data (G_OBJECT (object), "username");
 	pname   = g_object_get_data (G_OBJECT (object), "pilotname");
 	basedir = g_object_get_data (G_OBJECT (object), "basedir");
-#ifdef PILOT_LINK_0_12
 	charset = g_object_get_data (G_OBJECT (object), "charset");
-#endif
 	menu    = g_object_get_data (G_OBJECT (object), "sync_menu");
  	
 	num = gtk_entry_get_text (GTK_ENTRY (id));
@@ -688,11 +676,9 @@ read_pilot_config (GtkObject *object, GPilotPilot *pilot)
 		g_free (pilot->sync_options.basedir);
 	pilot->sync_options.basedir = g_strdup (gtk_entry_get_text (GTK_ENTRY (basedir)));
 
-#ifdef PILOT_LINK_0_12
 	if (pilot->pilot_charset)
 		g_free (pilot->pilot_charset);
 	pilot->pilot_charset = g_strdup (gtk_entry_get_text (GTK_ENTRY (charset)));
-#endif
 }
 
 void 
@@ -709,13 +695,10 @@ save_config_and_restart (GnomePilotClient *gpc, PilotState *state)
 gboolean
 check_device_settings (GPilotDevice *device, char **errstr)
 {	
-#ifndef WITH_HAL
 	struct stat buf;
 	char *usbdevicesfile_str ="/proc/bus/usb/devices";
 	char *sysfs_dir = "/sys/bus/usb/devices";
-#endif
 
-#ifdef PILOT_LINK_0_12
 	/* device->port is ignored for network and bluetooth syncs */
 	if (strcmp(device->port, "usb:") == 0 && device->type != PILOT_DEVICE_NETWORK
 	    && device->type != PILOT_DEVICE_BLUETOOTH
@@ -723,7 +706,6 @@ check_device_settings (GPilotDevice *device, char **errstr)
 		*errstr = g_strdup (_("Device 'usb:' is only valid for devices of type USB"));
 		return FALSE;
 	}
-#endif
 
 	if (device->type == PILOT_DEVICE_SERIAL) {
 		g_message ("checking rw on %s", device->port);
@@ -734,7 +716,6 @@ check_device_settings (GPilotDevice *device, char **errstr)
 					       _("Check the permissions on the device and retry"));
 			return FALSE;
 		}
-#ifndef WITH_HAL
 #ifdef linux
 	} else if (device->type == PILOT_DEVICE_USB_VISOR) {
 		/* check sysfs or usbfs is mounted */
@@ -751,7 +732,6 @@ check_device_settings (GPilotDevice *device, char **errstr)
 			return FALSE;
 		}
 #endif /* linux */
-#endif /* !WITH_HAL */
 	} 
 
 	return TRUE;
