@@ -22,7 +22,7 @@
  *
  */
 
-#include <gpilotd/gnome-pilot-client.h>
+#include <gnome-pilot-client.h>
 #include "pilot.h"
 
 /* Gui routines */
@@ -67,8 +67,8 @@ void error_dialog (GtkWindow *parent, gchar *mesg, ...);
 GPilotDevice *choose_pilot_dialog (PilotState *state);
 
 /* Configuration routines */
-void read_device_config (GtkObject *object, GPilotDevice* device);
-void read_pilot_config (GtkObject *object, GPilotPilot *pilot);
+void read_device_config (GObject *object, GPilotDevice* device);
+void read_pilot_config (GObject *object, GPilotPilot *pilot);
 
 void save_config_and_restart (GnomePilotClient *gpc, PilotState *state);
 
