@@ -29,7 +29,7 @@
 #include <stdio.h>
 #include <string.h>
 #include "gnome-pilot-structures.h"
-#include <gpilotd/gnome-pilot-config.h>
+#include <gnome-pilot-config.h>
 #include "gpilot-gui.h"
 #include <glib/gi18n.h>
 #include <errno.h>
@@ -401,9 +401,6 @@ gpilot_irda_device_deinit (GPilotDevice *device)
 static gint 
 gpilot_network_device_init (GPilotDevice *device)
 {
-#ifndef PILOT_LINK_0_12
-	struct pi_sockaddr addr;
-#endif
 #define MAXLINELEN 256
 	char line[MAXLINELEN];
 	char pi_net[100];
@@ -436,24 +433,14 @@ gpilot_network_device_init (GPilotDevice *device)
 			strncat(pi_net, "any", 3);
 		}
 	}
-#ifdef PILOT_LINK_0_12
 	device->fd = pi_socket (PI_AF_PILOT, PI_SOCK_STREAM, PI_PF_DLP);
-#else
-	device->fd = pi_socket (PI_AF_PILOT, PI_SOCK_STREAM, PI_PF_NET);
-#endif
 	if (device->fd < 0) {
 		g_warning ("Device [%s, %s]: Unable to get socket: %s", 
 		    device->name, pi_net, strerror(errno));
 		return -1;
 	}
 
-#ifdef PILOT_LINK_0_12
 	ret = pi_bind (device->fd, pi_net);
-#else
-	strncpy (addr.pi_device,pi_net, strlen(pi_net));
-
-	ret = pi_bind (device->fd, (struct sockaddr*)&addr, sizeof (addr));
-#endif
 	if (ret < 0) {
 		if (device->type == PILOT_DEVICE_BLUETOOTH) {
 			g_snprintf(line, MAXLINELEN,_("Bluetooth Device [%s]: Unable to "
@@ -771,7 +758,6 @@ gpilot_pilot_init (GPilotPilot *pilot,
 	pilot->romversion = g_key_file_get_integer (kfile, iPilot, "romversion", NULL);
 	pilot->number=i;
 	pilot->sync_options.basedir = g_key_file_get_string (kfile, iPilot, "basedir", NULL);
-#ifdef PILOT_LINK_0_12
 	pilot->pilot_charset = g_key_file_get_string (kfile, iPilot, "charset", NULL);
 	/* If no charset has been specified by user, fall back
 	 * to the PILOT_CHARSET environment variable, if that
@@ -789,9 +775,6 @@ gpilot_pilot_init (GPilotPilot *pilot,
 			    g_strdup (GPILOT_DEFAULT_CHARSET);
 		}
 	}
-#else
-	pilot->pilot_charset=NULL;
-#endif
 
 	g_key_file_free (kfile);
 	g_free (iPilot);
